@@ -1,5 +1,70 @@
 from .types import *
 
+
+class NetsplashGetInterfaces(NCSInstance):
+
+    _path = "/action/services/netsplash-get-interfaces"
+
+    _nsmap = {
+        "action":"urn:ietf:params:xml:ns:yang:1",
+        "services":"http://tail-f.com/ns/ncs",
+        "netsplash-get-interfaces":"http://umnet.umich.edu/netsplash",
+        }
+
+    def __init__(self):
+
+        self.ip_or_name = Choice(['device-hostname','device-ip'])
+        self.ip_or_name.device_ip = Leaf(str)
+        self.ip_or_name.device_hostname = Leaf(str)
+
+class NetsplashGetSwitchesByZone(NCSInstance):
+
+    _path = "/action/services/netsplash-get-switches-by-zone"
+
+    _nsmap = {
+        "action":"urn:ietf:params:xml:ns:yang:1",
+        "services":"http://tail-f.com/ns/ncs",
+        "netsplash-get-switches-by-zone":"http://umnet.umich.edu/netsplash",
+        }
+
+    def __init__(self):
+
+        self.zone = Leaf(str)
+
+
+class NetsplashUpdateInterfaces(NCSInstance):
+
+    _path = "/action/services/netsplash-update-interfaces"
+
+    _nsmap = {
+        "action":"urn:ietf:params:xml:ns:yang:1",
+        "services":"http://tail-f.com/ns/ncs",
+        "netsplash-update-interfaces":"http://umnet.umich.edu/netsplash",
+        }
+
+    def __init__(self):
+
+        self.switch = Leaf(str)
+        self.zone = Leaf(str)
+        self.switchport = List(NetsplashSwitchport)
+
+
+class NetsplashSwitchport(Choice):
+    
+    def __init__(self, choice=None):
+
+        # the choice initializer creates empty containers
+        # for 'access' and 'default' for us
+        super().__init__(['access','default'], choice=choice)
+        
+        # now we need to fill in everything else
+        self.name = Leaf(str)
+        self.access.description = Leaf(str)
+        self.access.vlan_name = Leaf(str)
+        self.access.admin_status = Leaf(str)
+        self.access.voip_enabled = Leaf(bool)
+
+
 class Devices(NCSInstance):
 
     _path = "/config/devices"
